@@ -24,18 +24,18 @@ class BrowserIntegrationTest(TestCase):
                     request.response.headers['Content-Type']
                 )
 
+        driver.quit()
+
     def test_firefox_can_access_requests(self):
         url = 'https://www.python.org/'
         driver = webdriver.Firefox()
         driver.get(url)
 
-        # request = driver.wait_for_request(url)
-        #
-        # self.assertEqual(request.response.status_code, 200)
-        # self.assertIn('text/html', request.response.headers['Content-Type'])
+        request = driver.wait_for_request(url)
+
+        self.assertEqual(request.response.status_code, 200)
+        self.assertIn('text/html', request.response.headers['Content-Type'])
 
-        import time
-        time.sleep(600)
         driver.quit()
 
     def test_firefox_can_access_requests_mitmproxy(self):
@@ -53,6 +53,30 @@ class BrowserIntegrationTest(TestCase):
 
         driver.quit()
 
+    def test_chrome_remote_debugger(self):
+        import subprocess
+        import time
+
+        def interceptor(request):
+            del request.headers['referer']
+            request.headers['referer'] = "https://www.test.com"
+
+        options = webdriver.ChromeOptions()
+        options.add_experimental_option("debuggerAddress", "127.0.0.1:12264")
+        chromeadres = '/usr/bin/google-chrome-stable'
+        subprocess.Popen([
+            chromeadres,
+            "--remote-debugging-port=12264",
+            "--ignore-certificate-errors",
+            "--proxy-server=http://localhost:12345"
+        ])
+        time.sleep(0.3)
+        driver = webdriver.Chrome(chrome_options=options, seleniumwire_options={'port': 12345})
+        driver.request_interceptor = interceptor
+        driver.get('https://www.whatismyreferer.com')
+
+        time.sleep(3)
+
     def test_chrome_can_access_requests(self):
         url = 'https://www.wikipedia.org/'
         driver = webdriver.Chrome()
@@ -96,36 +120,19 @@ class BrowserIntegrationTest(TestCase):
         driver.quit()
 
     def test_intercept_request(self):
-        url = 'https://guardian.co.uk'
+        url = 'https://python.org'
         user_agent = 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) ' \
                      'Chrome/28.0.1500.52 Safari/537.36 OPR/15.0.1147.100'
-        options = {
-            'proxy': {
-                'http': 'http://localhost:8081',
-                'https': 'https://localhost:8081'
-            },
-            # 'suppress_connection_errors': False
-        }
-        driver = webdriver.Firefox(seleniumwire_options=options)
+        driver = webdriver.Firefox()
 
         def intercept(req):
             del req.headers['User-Agent']
             req.headers['User-Agent'] = user_agent
-            # req.params = {**req.params, 'foo': 'bar'}
 
         driver.request_interceptor = intercept
 
         driver.get(url)
-        for request in driver.requests:
-            if request.response:
-                print(
-                    request.url, request.response.headers['Content-Type'], len(request.response.body)
-                )
 
-        # request = driver.wait_for_request(url)
-        #
-        # self.assertEqual(user_agent, request.headers['User-Agent'])
-        #
         driver.quit()
 
     def test_intercept_response(self):
@@ -217,18 +224,3 @@ class BrowserIntegrationTest(TestCase):
         driver.wait_for_request('https://www.wikipedia.org/')  # Should find www.wikipedia.org
 
         driver.quit()
-
-    def test_custom_response_handler(self):
-        """NOTE: this is being deprecated. Use driver.response_interceptor."""
-        def custom(req, req_body, res, res_body):
-            print(f'res_body length: {len(res_body)}')
-
-        options = {
-            'custom_response_handler': custom
-        }
-
-        driver = webdriver.Firefox(seleniumwire_options=options)
-
-        driver.get('https://www.python.org/')
-
-        driver.quit()
